{{ form.iommi_open_tag }}{% if not form.is_nested_form and form.attrs.method == 'post' %}<input type="hidden" name="csrfmiddlewaretoken" value="{{csrf_token}}"/>{% endif %}

    {{ form.h_tag }}

    {% block before_fields %}{% endblock %}

    {{ form.errors }}
    {{ form.render_fields }}

    {% block after_fields %}{% endblock %}

    {{ form.render_actions }}

    {% block after_actions %}{% endblock %}

{{ form.iommi_close_tag }}
